==> ldap-account-manager_8.0.1.orig.tar.bz2: ldap-account-manager-8.0.1/templates/lib/extra/ckeditor/plugins/table/lang/sl.js <==
/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'sl', {
	border: 'Velikost obrobe',
	caption: 'Napis',
	cell: {
		menu: 'Celica',
		insertBefore: 'Vstavi celico pred',
		insertAfter: 'Vstavi celico za',
		deleteCell: 'Izbriši celice',
		merge: 'Združi celice',
		mergeRight: 'Združi desno',
		mergeDown: 'Združi navzdol',
		splitHorizontal: 'Razdeli celico vodoravno',
		splitVertical: 'Razdeli celico navpično',
		title: 'Lastnosti celice',
		cellType: 'Vrsta celice',
		rowSpan: 'Razpon vrstic',
		colSpan: 'Razpon stolpcev',
		wordWrap: 'Prelom besedila',
		hAlign: 'Vodoravna poravnava',
		vAlign: 'Navpična poravnava',
		alignBaseline: 'Osnovnica',
		bgColor: 'Barva ozadja',
		borderColor: 'Barva obrobe',
		data: 'Podatki',
		header: 'Glava',
		yes: 'Da',
		no: 'Ne',
		invalidWidth: 'Širina celice mora biti število.',
		invalidHeight: 'Višina celice mora biti število.',
		invalidRowSpan: 'Razpon vrstic mora biti celo število.',
		invalidColSpan: 'Razpon stolpcev mora biti celo število.',
		chooseColor: 'Izberi'
	},
	cellPad: 'Odmik znotraj celic',
	cellSpace: 'Razmik med celicami',
	column: {
		menu: 'Stolpec',
		insertBefore: 'Vstavi stolpec pred',
		insertAfter: 'Vstavi stolpec za',
		deleteColumn: 'Izbriši stolpce'
	},
	columns: 'Stolpci',
	deleteTable: 'Izbriši tabelo',
	headers: 'Glave',
	headersBoth: 'Oboje',
	headersColumn: 'Prvi stolpec',
	headersNone: 'Brez',
	headersRow: 'Prva vrstica',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Širina obrobe mora biti število.',
	invalidCellPadding: 'Odmik znotraj celic mora biti pozitivno število.',
	invalidCellSpacing: 'Razmik med celicami mora biti pozitivno število.',
	invalidCols: 'Število stolpcev mora biti večje od 0.',
	invalidHeight: 'Višina tabele mora biti število.',
	invalidRows: 'Število vrstic mora biti večje od 0.',
	invalidWidth: 'Širina tabele mora biti število.',
	menu: 'Lastnosti tabele',
	row: {
		menu: 'Vrstica',
		insertBefore: 'Vstavi vrstico pred',
		insertAfter: 'Vstavi vrstico za',
		deleteRow: 'Izbriši vrstice'
	},
	rows: 'Vrstice',
	summary: 'Povzetek',
	title: 'Lastnosti tabele',
	toolbar: 'Tabela',
	widthPc: 'odstotkov',
	widthPx: 'pik',
	widthUnit: 'enota širine'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/sl.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'sl', {
	border: 'Velikost obrobe',
	caption: 'Napis',
	cell: {
		menu: 'Celica',
		insertBefore: 'Vstavi celico pred',
		insertAfter: 'Vstavi celico za',
		deleteCell: 'Izbriši celice',
		merge: 'Združi celice',
		mergeRight: 'Združi desno',
		mergeDown: 'Združi navzdol',
		splitHorizontal: 'Razdeli celico vodoravno',
		splitVertical: 'Razdeli celico navpično',
		title: 'Lastnosti celice',
		cellType: 'Vrsta celice',
		rowSpan: 'Razpon vrstic',
		colSpan: 'Razpon stolpcev',
		wordWrap: 'Prelom besedila',
		hAlign: 'Vodoravna poravnava',
		vAlign: 'Navpična poravnava',
		alignBaseline: 'Osnovnica',
		bgColor: 'Barva ozadja',
		borderColor: 'Barva obrobe',
		data: 'Podatki',
		header: 'Glava',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Da',
		no: 'Ne',
		invalidWidth: 'Širina celice mora biti število.',
		invalidHeight: 'Višina celice mora biti število.',
		invalidRowSpan: 'Razpon vrstic mora biti celo število.',
		invalidColSpan: 'Razpon stolpcev mora biti celo število.',
		chooseColor: 'Izberi'
	},
	cellPad: 'Odmik znotraj celic',
	cellSpace: 'Razmik med celicami',
	column: {
		menu: 'Stolpec',
		insertBefore: 'Vstavi stolpec pred',
		insertAfter: 'Vstavi stolpec za',
		deleteColumn: 'Izbriši stolpce'
	},
	columns: 'Stolpci',
	deleteTable: 'Izbriši tabelo',
	headers: 'Glave',
	headersBoth: 'Oboje',
	headersColumn: 'Prvi stolpec',
	headersNone: 'Brez',
	headersRow: 'Prva vrstica',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Širina obrobe mora biti število.',
	invalidCellPadding: 'Odmik znotraj celic mora biti pozitivno število.',
	invalidCellSpacing: 'Razmik med celicami mora biti pozitivno število.',
	invalidCols: 'Število stolpcev mora biti večje od 0.',
	invalidHeight: 'Višina tabele mora biti število.',
	invalidRows: 'Število vrstic mora biti večje od 0.',
	invalidWidth: 'Širina tabele mora biti število.',
	menu: 'Lastnosti tabele',
	row: {
		menu: 'Vrstica',
		insertBefore: 'Vstavi vrstico pred',
		insertAfter: 'Vstavi vrstico za',
		deleteRow: 'Izbriši vrstice'
	},
	rows: 'Vrstice',
	summary: 'Povzetek',
	title: 'Lastnosti tabele',
	toolbar: 'Tabela',
	widthPc: 'odstotkov',
	widthPx: 'pik',
	widthUnit: 'enota širine'
} );
